import { pino } from 'pino';

export const logger = pino({
  level: process.env.LOG_LEVEL || 'info',
  transport: {
    target: 'pino-pretty',
    options: {
      colorize: true,
      translateTime: 'SYS:standard',
      ignore: 'pid,hostname',
    },
  },
  serializers: {
    error: pino.stdSerializers.err,
    req: pino.stdSerializers.req,
    res: pino.stdSerializers.res,
  },
  base: {
    app: 'assistant',
    env: process.env.NODE_ENV || 'production',
  },
});
export const console = {
  log: logger.info,
  error: logger.error,
  warn: logger.warn,
  info: logger.info,
  debug: logger.debug,
};

export const logError = (message: string, data?: any) => logger.error({ data }, message);
export const logWarning = (message: string, data?: any) => logger.warn({ data }, message);
export const logInfo = (message: string, data?: any) => logger.info({ data }, message);
export const logDebug = (message: string, data?: any) => logger.debug({ data }, message);

export const log = {
  log: logInfo,
  error: logError,
  warn: logWarning,
  info: logInfo,
  debug: logDebug,
};
